@@ -11,7 +11,7 @@ use warnings;
 #my $VERSION="0.1";
 
 #For CVS , use following line
-our $VERSION=sprintf("%d.%04d", q$Revision: 2006.0626 $ =~ /(\d+)\.(\d+)/);
+our $VERSION=sprintf("%d.%04d", q$Revision: 2008.0606 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {
 
@@ -58,10 +58,6 @@ __PACKAGE__ =~ m/^(WWW::[^:]+)((::([^:]+)){1}(::([^:]+)){0,1}){0,1}$/g;
    'export_ok'      => [],
    'urls' =>
    {
-      ##
-      ## vlbt_opts
-      ##
-
    },
    'opts_type_flag' =>
    [
@@ -69,10 +65,6 @@ __PACKAGE__ =~ m/^(WWW::[^:]+)((::([^:]+)){1}(::([^:]+)){0,1}){0,1}$/g;
    'opts_type_numeric' =>
    [
       'delay_sec',
-
-      ##
-      ## vlbt_opts
-      ##
       'first_page',
       'max_pages',
       'last_page',
@@ -81,9 +73,6 @@ __PACKAGE__ =~ m/^(WWW::[^:]+)((::([^:]+)){1}(::([^:]+)){0,1}){0,1}$/g;
    ],
    'opts_type_string' =>
    [
-      ##
-      ## vlbt_opts
-      ##
       'tag',
       'vlbt_want',
 
@@ -110,7 +99,7 @@ $WWW::YouTube::ML::numeric_delay_sec = WWW::YouTube::ML::numeric_delay_sec(); ##
 
 $WWW::YouTube::ML::string_tag = undef;
 
-$WWW::YouTube::ML::string_vlbt_want = $WWW::YouTube::ML::API::string_vlbt_want;
+$WWW::YouTube::ML::string_vlbt_want = 'all';
 
 ##debug##WWW::YouTube::ML::API::show_all_opts( \%WWW::YouTube::ML::opts_type_args );
 
@@ -316,20 +305,18 @@ sub WWW::YouTube::ML::vlbt
    ## ML: so I can make XML curr_page calls right and set HTML curr_page, etc. ## What? To myself.
    ##
 
-   $WWW::YouTube::ML::API::string_vlbt_want = $WWW::YouTube::ML::string_vlbt_want; ## ML::API bogus
-
-   if ( $WWW::YouTube::ML::API::string_vlbt_want ne 'all' )
+   if ( $WWW::YouTube::ML::string_vlbt_want ne 'all' )
    {
-      $WWW::YouTube::XML::API::string_vlbt_want = $WWW::YouTube::ML::API::string_vlbt_want;
+      $WWW::YouTube::XML::string_vlbt_want = $WWW::YouTube::ML::string_vlbt_want;
 
-      $WWW::YouTube::HTML::API::string_vlbt_want = $WWW::YouTube::ML::API::string_vlbt_want;
+      $WWW::YouTube::HTML::string_vlbt_want = $WWW::YouTube::ML::string_vlbt_want;
 
    }
-   elsif ( $WWW::YouTube::XML::API::string_vlbt_want eq $WWW::YouTube::HTML::API::string_vlbt_want )
+   elsif ( $WWW::YouTube::XML::string_vlbt_want eq $WWW::YouTube::HTML::string_vlbt_want )
    {
-      $WWW::YouTube::ML::string_vlbt_want = $WWW::YouTube::XML::API::string_vlbt_want;
+      $WWW::YouTube::ML::string_vlbt_want = $WWW::YouTube::XML::string_vlbt_want;
 
-      $WWW::YouTube::ML::API::string_vlbt_want = $WWW::YouTube::HTML::API::string_vlbt_want;
+      $WWW::YouTube::ML::string_vlbt_want = $WWW::YouTube::HTML::string_vlbt_want;
 
    } # end if
 
@@ -378,8 +365,8 @@ sub WWW::YouTube::ML::vlbt
 
    $h->{'video_list'}->{'tag'} = $h->{'tag'};
 
-   if ( ( $WWW::YouTube::XML::API::string_vlbt_want ne 'none' ) ||
-        ( $WWW::YouTube::HTML::API::string_vlbt_want ne 'none' )
+   if ( ( $WWW::YouTube::XML::string_vlbt_want ne 'none' ) ||
+        ( $WWW::YouTube::HTML::string_vlbt_want ne 'none' )
       )
    {
       $h = WWW::YouTube::XML::vlbt( $h ); ## does just='all' marking found_tagged=boolean;
@@ -391,27 +378,27 @@ sub WWW::YouTube::ML::vlbt
 
    } ## end if
 
-   if ( $WWW::YouTube::HTML::API::string_vlbt_want ne 'none' )
+   if ( $WWW::YouTube::HTML::string_vlbt_want ne 'none' )
    {
       mkdir( $h->{'wrkdir'} ) if ( ! -e $h->{'wrkdir'} ); ## if needed
 
-      $h->{'video_list'}->{'just'} = $WWW::YouTube::HTML::API::string_vlbt_want;
+      $h->{'video_list'}->{'just'} = $WWW::YouTube::HTML::string_vlbt_want;
 
       $h = WWW::YouTube::HTML::vlbt( $h );
 
    } ## end if
 
-   if ( $WWW::YouTube::XML::API::string_vlbt_want ne 'none' )
+   if ( $WWW::YouTube::XML::string_vlbt_want ne 'none' )
    {
       mkdir $h->{'wrkdir'} if ( ! -e $h->{'wrkdir'} ); ## if needed
 
       my $myxmldumper = XML::Dumper->new();
 
-      my $myxml = "$h->{'wrkdir'}/video_list.xml.gz";
+      my $myxml = "$h->{'wrkdir'}/video_list.xml";
 
-      $h->{'video_list'}->{'just'} = $WWW::YouTube::XML::API::string_vlbt_want;
+      $h->{'video_list'}->{'just'} = $WWW::YouTube::XML::string_vlbt_want;
 
-      if ( $WWW::YouTube::XML::API::string_vlbt_want ne 'all' )
+      if ( $WWW::YouTube::XML::string_vlbt_want ne 'all' )
       {
          ##
          ## Cull
@@ -459,19 +446,6 @@ sub WWW::YouTube::ML::vlbt
 
 } ## end sub WWW::YouTube::ML::vlbt
 
-#=cut
-#   if ( ! defined( $h->{'tag'} ) )
-#   {
-#      my $term = Term::ReadLine->new('vlbt');
-#
-#      $h->{'tag'} = $term->get_reply(
-#                           'prompt' => 'What tag do you want?',
-#                           'default' => $h->{'tag_dir'},
-#                                    );
-#
-#   } ## end if
-#=cut
-
 1;
 __END__ ## package WWW::YouTube::ML
 
@@ -481,8 +455,6 @@ WWW::YouTube::ML - WWW::YouTube Markup Language, an Abstraction Layer
 
 =head1 SYNOPSIS
 
-Options (--ml_* options);
-
 =head1 OPTIONS
 
 --ml_* options:
@@ -514,6 +486,6 @@ I<L<WWW::YouTube>> I<L<WWW::YouTube::ML::API>> I<L<WWW::YouTube::HTML>> I<L<WWW:
 
 =head1 AUTHOR
 
- Copyright (C) 2006 Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>
+ Copyright (C) 2008 Eric R. Meyers E<lt>Eric.R.Meyers@gmail.comE<gt>
 
 =cut
